==> clickhouse_tools_abm-3.1.54618a0.tar.gz: clickhouse_tools_abm-3.1.54618a0/clickhouse_tools/qpel_helper/expresions/functions/comparison.py <==
#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Vasiliev Ivan <i.vasiliev@technokert.ru>
from dataclasses import dataclass, field
from typing import Iterable, Callable

from clickhouse_tools.elements.filter_by import Condition as ChCondition, ComparisonOperator, Filter
from qpel_helper.expresions.base import  AbstractFactory
from qpel_helper.expresions.functions.function import Function, FunctionArgType


@dataclass
class Comparison(Function):

    def __post_init__(self):
        self.name = self.name.lower()

    def __call__(self, left: FunctionArgType, right: FunctionArgType) -> ChCondition | Filter:
        super(Comparison, self).__call__(left, right )
        return Filter(attribute=left, value=right, operator=getattr(ComparisonOperator, self.name))


@dataclass
class Condition(Function):
    condition: ChCondition = field(init=False, default_factory=ChCondition,)

    def __call__(self, *condition_args: Iterable) -> ChCondition:
        super(Condition, self).__call__(condition_args)
        handler = self._choose_handler()
        for arg in condition_args:
            handler(arg)
        return self.condition

    def _choose_handler(self) -> Callable:
        if self.name == "or":
            return self.condition.add_or
        if self.name == "and":
            return self.condition.add_and
        raise KeyError(f"unknown handler for {self.name}")


class ConditionFactory(AbstractFactory):
    condition_keys = {"or", "and"}
    comparison_keys = {comparison_name for comparison_name in ComparisonOperator.get_member_names()}
    # comparison_replacement = {}

    def __getattr__(self, key: str):
        if key in self.condition_keys:
            return Condition(key)
        elif key in self.comparison_keys:
            return Comparison(key)
        raise KeyError(f"unknown handler for {self.name}")

==> clickhouse_tools_abm-3.1.54620a0.tar.gz: clickhouse_tools_abm-3.1.54620a0/clickhouse_tools/qpel_helper/expresions/functions/comparison.py <==
#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Vasiliev Ivan <i.vasiliev@technokert.ru>
from dataclasses import dataclass, field
from typing import Iterable, Callable

from clickhouse_tools.elements.filter_by import Condition as ChCondition, ComparisonOperator, Filter
from ..base import AbstractFactory
from .function import Function, FunctionArgType


@dataclass
class Comparison(Function):

    def __post_init__(self):
        self.name = self.name.lower()

    def __call__(self, left: FunctionArgType, right: FunctionArgType) -> ChCondition | Filter:
        super(Comparison, self).__call__(left, right )
        return Filter(attribute=left, value=right, operator=getattr(ComparisonOperator, self.name))


@dataclass
class Condition(Function):
    condition: ChCondition = field(init=False, default_factory=ChCondition,)

    def __call__(self, *condition_args: Iterable) -> ChCondition:
        super(Condition, self).__call__(condition_args)
        handler = self._choose_handler()
        for arg in condition_args:
            handler(arg)
        return self.condition

    def _choose_handler(self) -> Callable:
        if self.name == "or":
            return self.condition.add_or
        if self.name == "and":
            return self.condition.add_and
        raise KeyError(f"unknown handler for {self.name}")


class ConditionFactory(AbstractFactory):
    condition_keys = {"or", "and"}
    comparison_keys = {comparison_name for comparison_name in ComparisonOperator.get_member_names()}
    # comparison_replacement = {}

    def __getattr__(self, key: str):
        if key in self.condition_keys:
            return Condition(key)
        elif key in self.comparison_keys:
            return Comparison(key)
        raise KeyError(f"unknown handler for {self.name}")
